@@ -3,7 +3,8 @@ import os
 from datetime import datetime
 
 import pkg_resources
-from paperscraper.get_dumps.utils.chemrxiv import ChemrxivAPI, download_full, parse_dump
+
+from .utils.chemrxiv import ChemrxivAPI, download_full, parse_dump
 
 today = datetime.today().strftime('%Y-%m-%d')
 save_folder = pkg_resources.resource_filename('paperscraper', 'server_dumps')
