@@ -15,7 +15,9 @@ def aggregate_paper(
     bins_per_year: int = 4,
     filtering: bool = False,
     filter_keys: List = list(),
+    unwanted_keys: List = list(),
     return_filtered: bool = False,
+    last_year: int = 2021,
 ):
     """Consumes a list of unstructured keyword results from a .jsonl and
     aggregates papers into several bins per year.
@@ -30,9 +32,12 @@ def aggregate_paper(
             the keywords is performed in abstract/title. Defaults to False.
         filter_keys (list, optional): List of str used for filtering. Only
             applies if filtering is True. Defaults to empty list.
+        unwanted_keys (list, optional): List of str that must not occur in either
+            title or abstract. Only applies if filtering is True.
         return_filtered (bool, optional): Whether the filtered matches are also
             returned. Only applies if filtering is True. Defaults to False.
-
+        last_year (int, optional): Most recent year for the aggregation. Defaults
+            to current year. All newer entries are discarded.
 
     Returns:
         bins (np.array): Vector of length number of years (2020 - start_year) x
@@ -46,7 +51,7 @@ def aggregate_paper(
     if 12 % bins_per_year != 0:
         raise ValueError(f'Cant split year into {bins_per_year} bins')
 
-    num_years = 2020 - start_year + 1
+    num_years = last_year - start_year + 1
     bins = np.zeros((num_years * bins_per_year))
 
     # Read data
@@ -64,16 +69,31 @@ def aggregate_paper(
     filtered = []
     for paper, date in zip(data, dates):
         year = int(date.split('-')[0])
-        if year < start_year:
+        if year < start_year or year > last_year:
             continue
 
         # At least one synonym per keyword needs to be in either title or
         # abstract.
         if filtering and filter_keys != list():
 
+            # Filter out papers which undesired terms
+            unwanted = False
+            for unwanted_key in unwanted_keys:
+                if unwanted_key.lower() in paper['title'].lower():
+                    unwanted = True
+                if (
+                    paper['abstract'] is not None
+                    and unwanted_key.lower() in paper['abstract'].lower()
+                ):
+                    unwanted = True
+            if unwanted:
+                continue
+
             got_keys = []
             for key_term in filter_keys:
                 got_key = False
+                if not isinstance(key_term, list):
+                    key_term = [key_term]
                 for key in key_term:
                     if key.lower() in paper['title'].lower():
                         got_key = True
